==> yosmapa_0.18-2.tar.gz: yosmapa-0.18/src/opt/yosmapa/plugins/fotoradary.py <==
import gtk
import gtk.gdk
from gtk import gdk
import hildon
import time
import xml.dom.minidom,os
from xml.dom.minidom import Node
import osmgpsmap
import math
import cairo


class fotoradary:

    def __init__(self,osmMapa,CONFIG):
        self.CONFIG = CONFIG

        self.ico = "fotoradary.png"
        self.osmMapa = osmMapa
        self.CONFIG = CONFIG
        self.file = "./plugins/fotoradary.txt"
        self.f = []
        self.f_images = []
        self.box_old = 0,0,0,0
        self.zoom_old = 0

        self.from_zoom = 13

        print "__init__ fotoradary"


    def f_rebuild(self):
        box = self.osmMapa.osm.get_bbox()
        t_lt, t_ln, b_lt, b_ln = box
        if self.box_old <> box or self.zoom_old <> self.osmMapa.osm.props.zoom :
            t_lt, t_ln, b_lt, b_ln = math.degrees(t_lt), math.degrees(t_ln), math.degrees(b_lt), math.degrees(b_ln)

            self.clean_layer()
            for pa in self.f:

                lt = float(pa[0])
                ln = float(pa[1])

                if t_ln < ln and b_ln > ln and t_lt > lt and b_lt < lt:
                    i = gdk.pixbuf_new_from_file("./plugins/fotoradary.png")
                    self.f_images.append( self.osmMapa.osm.image_add( lt, ln, i ) )

            self.box_old = box
            self.zoom_old = self.osmMapa.osm.props.zoom

    def clean_layer(self):
        for pr in self.f_images:
            self.osmMapa.osm.image_remove(pr)
        self.f_images = []

    def killIt(self):
        self.clean_layer()

    def makeInit(self):
        self.box_old = 0,0,0,0
        f = open( self.file, "r" )
        l = 1
        while l:
            try:
                l = f.readline()
                t = l.split(",")
                if len(t) == 6 and t[0].find(".") != -1:
                    self.f.append( [float(t[1]),float(t[0]),t[3]])
            except:
                pass
        print "fotoradary read poi xml found (",len(self.f),") POI :)"

        if self.osmMapa.osm.props.zoom>self.from_zoom:
            self.f_rebuild()


    def get_menu_widgets(self, dialog):
        return None

    def get_name(self):
        return "fotoradary"

    def do_draw(self, gpsmap, gdkdrawable):
        if self.osmMapa.osm.props.zoom>self.from_zoom:
            self.f_rebuild()
        else:
            self.clean_layer()


    def do_render(self, gpsmap):
        pass

    def do_busy(self):
        return False

    def do_button_press(self, gpsmap, gdkeventbutton):
        return False

==> yosmapa_0.18-3.tar.gz: yosmapa-0.18/src/opt/yosmapa/plugins/fotoradary.py <==
import gtk
import gtk.gdk
from gtk import gdk
import hildon
import time
import xml.dom.minidom,os
from xml.dom.minidom import Node
import osmgpsmap
import math
import cairo


class fotoradary:

    def __init__(self,osmMapa,CONFIG):
        self.CONFIG = CONFIG

        self.ico = "fotoradary.png"
        self.osmMapa = osmMapa
        self.CONFIG = CONFIG
        self.file = "./plugins/fotoradary.txt"
        self.ico_fotoradar = gdk.pixbuf_new_from_file("./plugins/fotoradary.png")
        self.f = []
        self.f_images = []
        self.box_old = 0,0,0,0
        self.zoom_old = 0

        self.from_zoom = 13

        print "__init__ fotoradary"


    def f_rebuild(self):
        box = self.osmMapa.osm.get_bbox()
        t_lt, t_ln, b_lt, b_ln = box
        if self.box_old <> box or self.zoom_old <> self.osmMapa.osm.props.zoom :
            t_lt, t_ln, b_lt, b_ln = math.degrees(t_lt), math.degrees(t_ln), math.degrees(b_lt), math.degrees(b_ln)

            self.clean_layer()
            for pa in self.f:

                lt = float(pa[0])
                ln = float(pa[1])

                if t_ln < ln and b_ln > ln and t_lt > lt and b_lt < lt:
                    self.f_images.append( self.osmMapa.osm.image_add( lt, ln, self.ico_fotoradar ) )

            self.box_old = box
            self.zoom_old = self.osmMapa.osm.props.zoom

    def clean_layer(self):
        for pr in self.f_images:
            self.osmMapa.osm.image_remove(pr)
        self.f_images = []

    def killIt(self):
        self.clean_layer()

    def makeInit(self):
        self.box_old = 0,0,0,0
        f = open( self.file, "r" )
        l = 1
        while l:
            try:
                l = f.readline()
                t = l.split(",")
                if len(t) == 6 and t[0].find(".") != -1:
                    self.f.append( [float(t[1]),float(t[0]),t[3]])
            except:
                pass
        print "fotoradary read poi xml found (",len(self.f),") POI :)"

        if self.osmMapa.osm.props.zoom>self.from_zoom:
            self.f_rebuild()


    def get_menu_widgets(self, dialog):
        return None

    def get_name(self):
        return "fotoradary"

    def do_draw(self, gpsmap, gdkdrawable):
        if self.osmMapa.osm.props.zoom>self.from_zoom:
            self.f_rebuild()
        else:
            self.clean_layer()


    def do_render(self, gpsmap):
        pass

    def do_busy(self):
        return False

    def do_button_press(self, gpsmap, gdkeventbutton):
        return False
